@@ -4,10 +4,10 @@
  * Functions for the portmap spoofer
  */
 
-#ifndef KINIT_DUMMYPORTMAP_H
-#define KINIT_DUMMYPORTMAP_H
+#ifndef NFSMOUNT_DUMMYPORTMAP_H
+#define NFSMOUNT_DUMMYPORTMAP_H
 
 #include <unistd.h>
 pid_t start_dummy_portmap(const char *file);
 
-#endif				/* KINIT_DUMMYPORTMAP_H */
+#endif /* NFSMOUNT_DUMMYPORTMAP_H */
